
[![CI](https://github.com/opensearch-project/opensearch-py-ml/actions/workflows/ci.yml/badge.svg)](https://github.com/opensearch-project/opensearch-py-ml/actions/workflows/ci.yml)
[![Integration](https://github.com/opensearch-project/opensearch-py-ml/actions/workflows/integration.yml/badge.svg)](https://github.com/opensearch-project/opensearch-py-ml/actions/workflows/integration.yml)
![PRs welcome!](https://img.shields.io/badge/PRs-welcome!-success)

![OpenSearch logo](https://github.com/opensearch-project/opensearch-py/raw/main/OpenSearch.svg)

OpenSearch-py-ml

- [Welcome!](https://github.com/opensearch-project/opensearch-py-ml#welcome)
- [Getting Started](https://github.com/opensearch-project/opensearch-py-ml#getting-started)
- [Compatibility with OpenSearch](https://github.com/opensearch-project/opensearch-py-ml#compatibility-with-opensearch)
- [Project Resources](https://github.com/opensearch-project/opensearch-py-ml#project-resources)
- [Code of Conduct](https://github.com/opensearch-project/opensearch-py-ml#code-of-conduct)
- [License](https://github.com/opensearch-project/opensearch-py-ml#license)
- [Copyright](https://github.com/opensearch-project/opensearch-py-ml#copyright)

## Welcome!

**opensearch-py-ml** is a Python client that provides a suite of data analytics and machine learning tools for OpenSearch.

It is [a community-driven, open source fork](https://aws.amazon.com/blogs/opensource/introducing-opensearch/) a fork of [eland](https://github.com/elastic/eland), which provides data analysis and machine learning
licensed under the [Apache v2.0 License](https://github.com/opensearch-project/opensearch-py/blob/main/LICENSE.txt). 

**opensearch-py-ml** lets users call OpenSearch indices and manipulate them as if they were pandas DataFrames, supporting
complex filtering and aggregation operations. It also provides rudimentary support for uploading models to OpenSearch
clusters using the [ml-commons](https://github.com/opensearch-project/ml-commons) plugin.


For more information, see [opensearch.org](https://opensearch.org/docs/latest/clients/opensearch-py-ml/) and the [API Doc](https://opensearch-project.github.io/opensearch-py-ml/index.html).


## Installing Opensearch-py-ml


Opensearch-py-ml can be installed from [PyPI](https://pypi.org/project/opensearch-py-ml) via pip:

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    $ python -m pip install opensearch-py-ml
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

## Code of Conduct

This project has adopted the 
[Amazon Open Source Code of Conduct](https://github.com/opensearch-project/opensearch-py-ml/blob/main/CODE_OF_CONDUCT.md).
For more information see the [Code of Conduct FAQ](https://aws.github.io/code-of-conduct-faq), or contact 
[opensource-codeofconduct@amazon.com](mailto:opensource-codeofconduct@amazon.com) with any additional questions or comments.

## License

This project is licensed under the
[Apache v2.0 License](https://github.com/opensearch-project/opensearch-py-ml/blob/main/LICENSE).

## Copyright

Copyright OpenSearch Contributors. See 
[NOTICE](https://github.com/opensearch-project/opensearch-py-ml/blob/main/NOTICE) for details.
